@@ -48,7 +48,7 @@ class KadenaSdk():
 
 
   def build_command(self, 
-    payload: ExecPayload | ContPayload,
+    payload: dict,
     chain_ids: list[str],
     signers: list[str]=None, 
     sender: str=None, 
